@@ -72,6 +72,11 @@ use DBI;
 use FusqlFS::Entry;
 
 our %FORMATTERS = (
+    native => [
+        undef,
+        sub () { $_[0] },
+        sub () { $_[0] },
+        ],
     xml => [
         'XML/Simple.pm',
         sub () { XMLout($_[0], NoAttr => 1) },
@@ -133,7 +138,7 @@ sub new
     $self->{dbh} = $self->{connect}();
 
     my $formatter = $FORMATTERS{$format} || $FORMATTERS{yaml};
-    require $formatter->[0];
+    require $formatter->[0] if $formatter->[0];
     $self->{dumper} = $formatter->[1];
     $self->{loader} = $formatter->[2];
 
