@@ -1,5 +1,5 @@
 use strict;
-use v5.10.0;
+use 5.010;
 
 =head1 NAME
 
@@ -56,7 +56,8 @@ Synlink to language owner role in F<../../roles>.
 =cut
 
 package FusqlFS::Backend::PgSQL::Languages;
-our $VERSION = "0.005";
+use FusqlFS::Version;
+our $VERSION = $FusqlFS::Version::VERSION;
 use parent 'FusqlFS::Artifact';
 
 use FusqlFS::Backend::PgSQL::Role::Owner;
@@ -136,7 +137,7 @@ sub get
 
 my $list = $_tobj->list();
 isa_ok $list, 'ARRAY';
-cmp_set $list, [ qw(c internal sql) ];
+cmp_set $list, [ qw(c internal sql plpgsql) ];
 
 =end testing
 =cut
@@ -151,7 +152,7 @@ sub list
 =begin testing drop after rename
 
 isnt $_tobj->drop('plperl1'), undef;
-cmp_set $_tobj->list(), [ qw(c internal sql) ];
+cmp_set $_tobj->list(), [ qw(c internal sql plpgsql) ];
 is $_tobj->get('plperl1'), undef;
 
 =end testing
@@ -169,7 +170,7 @@ sub drop
 
 isnt $_tobj->create('plperl'), undef;
 is_deeply $_tobj->get('plperl'), $new_lang;
-cmp_set $_tobj->list(), [ qw(c internal sql plperl) ];
+cmp_set $_tobj->list(), [ qw(c internal sql plpgsql plperl) ];
 
 =end testing
 =cut
@@ -185,7 +186,7 @@ sub create
 =begin testing rename after store
 
 isnt $_tobj->rename('plperl', 'plperl1'), undef;
-cmp_set $_tobj->list(), [ qw(c internal sql plperl1) ];
+cmp_set $_tobj->list(), [ qw(c internal sql plpgsql plperl1) ];
 is $_tobj->get('plperl'), undef;
 is_deeply $_tobj->get('plperl1'), $new_lang;
 
